@extends(get_theme().'.components.layouts')

@php
    $this_episode = isset($episode_info) ? $episode_info->episode_number : false;
    $season = $season ?? $tv->number_of_seasons;
@endphp

@section('footer')
    <script src="{{ asset_theme('assets/s.js') }}"></script>
@endsection

@section('content')
    <section class="px-4r">
        <div class="backdrop" style="background-image: url({{ img_backdrop($backdrop) }})"></div>
        <div class="container">
            @include(get_theme().'.components.player', ['backdrop' => $backdrop, 'video' => asset_theme('/assets/movie.mp4')])
            <script>var playDuration = 129*60;</script>
        </div>
        <div class="container py-4">
            <div class="row">
                <div class="col d-flex justify-content-center">
                    <a href="{{ route('loading', ['id' => $tv->id ,'title' => $tv->original_name, 'action' => 'play']) }}" class="btn btn-outline-theme mx-1">{{ __('utilities.watch_now') }} <i class="fa fa-film" aria-hidden="true"></i></a>
                    <a href="{{ route('loading', ['id' => $tv->id ,'title' => $tv->original_name, 'action' => 'register']) }}" class="btn btn-outline-theme mx-1">{{ __('utilities.download') }} <i class="fa fa-cloud-download" aria-hidden="true"></i></a>
                </div>
            </div>
        </div>
    </section>

    <section class="container p-3 p-md-4 rounded-lg mb-5" style="background-color: #0e1117">
        <div class="row">
            <div class="col-12">
                <div class="row">
                    <div class="col-md-2 col-sm-4 col-3">
                        <img class="img-fluid" src="{{ img_poster($tv->poster_path) }}" alt="Poster {{ $title }} {{ to_year($air_date) }}" title="Poster {{ $title }} {{ to_year($air_date) }}">
                    </div>
                    <div class="col-md-10 col-sm-8 col-9">
                        <div class="entry-title d-flex flex-column-reverse flex-md-row justify-content-between">
                            <h1 class="h2">{{ $title }} <span class="tiny text-muted">{{ to_year($air_date) }}</span></h1>
                            <div class="sub-r">
                                <a href="{{ route('loading', ['id' => $tv->id ,'title' => $tv->original_name]) }}" class="btn subs">{{ __('utilities.subscribe_watch') }}</a>
                            </div>
                        </div>
                        <div class="entry-info mb-3">
                            <div class="__rate">
                                @for ($i = 0; $i < 10; $i++)
                                    @if ($i < round($tv->vote_average))
                                        <i class="fa fa-star text-warning"></i>
                                    @else
                                        <i class="fa fa-star-o text-muted"></i>
                                    @endif
                                @endfor
                            </div>
                            <div class="__info">
                                <span class="text-muted small">{{ $tv->vote_average }}/10</span> <span class="text-muted small">{{ __('utilities.by') }} {{ $tv->vote_count }} {{ __('utilities.users') }}</span>
                            </div>
                        </div>
                        <div class="entry-desciption text-muted">
                            <p>{{ $overview }}</p>
                        </div>
                        <div class="entry-table">
                            <ul>
                                <li>{{ __('utilities.released') }}: <span>{{ $air_date }}</span></li>
                                <li>{{ __('utilities.runtime') }}: <span>{{ $tv->episode_run_time[0] }} {{ __('utilities.minutes') }}</span></li>
                                <li>{{ __('utilities.genre') }}: <span>{{ collect($tv->genres)->implode('name', ', ') }}</span></li>
                                <li>{{ __('utilities.stars') }}: <span>{!! star_comma($tv->credits->cast, 5) !!}</span></li>
                                <li>{{ __('utilities.director') }}: <span>{!! director_comma($tv->credits->crew, 5) !!}</span></li>
                            </ul>
                        </div>
                    </div>

                    <div class="col-12">
                        <div class="episodes">
                            <div>
                                <ul class="nav nav-tabs" id="episodesTab" role="tablist" style="height: auto">
                                    @foreach (collect($tv->seasons)->sortKeysDesc()->all() as $item)
                                        <li class="nav-item">
                                            <a href="{{ route('tv.single.season', ['id' => $tv->id, 'season' => $item->season_number, 'slug' => Str::slug($tv->original_name)]) }}" class="nav-link {{ $item->season_number == $season ? 'active' : '' }}" id="season-{{ $item->season_number }}-tab">
                                                {{ __('utilities.season') }} {{ $item->season_number }}
                                            </a>
                                        </li>
                                    @endforeach
                                </ul>
                            </div>
                        </div>
                        <div class="tab-content episodes_list" id="episodesTabContent">
                            <div class="tab-pane fade show active" id="season-{{ $tv->number_of_seasons }}" role="tabpanel" aria-labelledby="season-{{ $tv->number_of_seasons }}-tab">
                                <ul>
                                    @foreach ($season_select as $item)
                                        @if ($item->episode_number == $this_episode)
                                            <li class="dark">
                                        @else
                                            <li>
                                        @endif
                                            <div class="episodes_list_item">
                                                <div>
                                                    <a class="episodes_list_episode" href="{{ route('tv.single.season.episode', ['id'=>$tv->id, 'season' => $season, 'episode'=>$item->episode_number, 'slug' => Str::slug($tv->original_name.' '.$item->name) ]) }}" title="{{ $item->name }}">{{$item->episode_number }}. {{ $item->name }}</a>
                                                    <span class="episodes_list_release">{{ $item->air_date }}</span>
                                                </div>
                                                <div>
                                                    <a class="episodes_list_watch" href="{{ route('tv.single.season.episode', ['id'=>$tv->id, 'season' => $season, 'episode'=>$item->episode_number, 'slug' => Str::slug($tv->original_name.' '.$item->name) ]) }}"><i class="fa fa-lg fa-play-circle"></i> <span>{{ __('utilities.watch') }}</span></a>
                                                </div>
                                            </div>
                                        </li>
                                    @endforeach
                                </ul>
                            </div>
                        </div>
                    </div>

                </div>
            </div>
        </div>
    </section>

    <section class="container p-3 p-md-4 rounded-lg mb-5" style="background-color: #0e1117">
        <div class="h6">{{ __('utilities.download') }} : <strong class="text-color-theme">MKV</strong></div>
        <ul class="down-list mb-4">
            <li>
                <div class="dt"><strong>360p</strong></div>
                <span>GD2</span> | <span>CU</span> | <span>GD1</span> | <span>ZS</span> | <span>RC</span>
            </li>
            <li>
                <div class="dt"><strong>480p</strong></div>
                <span>GD2</span> | <span>CU</span> | <span>GD1</span> | <span>ZS</span> | <span>RC</span>
            </li>
            <li>
                <div class="dt"><strong>720p</strong></div>
                <span>GD2</span> | <span>CU</span> | <span>GD1</span> | <span>ZS</span> | <span>RC</span>
            </li>
            <li>
                <div class="dt"><strong>1080p</strong></div>
                <span>GD2</span> | <span>CU</span> | <span>GD1</span> | <span>ZS</span> | <span>RC</span>
            </li>
        </ul>
        <div class="h6">{{ __('utilities.download') }} : <strong class="text-color-theme">MP4</strong></div>
        <ul class="down-list">
            <li>
                <div class="dt"><strong>360p</strong></div>
                <span>GD2</span> | <span>CU</span> | <span>GD1</span> | <span>ZS</span> | <span>RC</span>
            </li>
            <li>
                <div class="dt"><strong>480p</strong></div>
                <span>GD2</span> | <span>CU</span> | <span>GD1</span> | <span>ZS</span> | <span>RC</span>
            </li>
            <li>
                <div class="dt"><strong>MP4HD</strong></div>
                <span>GD2</span> | <span>CU</span> | <span>GD1</span> | <span>ZS</span> | <span>RC</span>
            </li>
            <li>
                <div class="dt"><strong>FULLHD</strong></div>
                <span>GD2</span> | <span>CU</span> | <span>GD1</span> | <span>ZS</span> | <span>RC</span>
            </li>
        </ul>
    </section>

    <section class="container">
        @isset($tv->similar)
            <div class="row">
                <div class="col-12 mb-4">
                    <h3 class="h4">{{ __('section.title.similar') }}</h3>
                </div>
            </div>
            <div class="owl-carousel">
                @foreach (block_id_lists($tv->similar->results) as $item)
                    @include(get_theme().'.components.item_tv', ['class' => ''])
                @endforeach
            </div>
        @endisset
        @isset($tv->recommendations)
            <div class="divider"></div>
            <div class="row">
                <div class="col-12 mb-4">
                    <h3 class="h4">{{ __('section.title.recommendation') }}</h3>
                </div>
            </div>
            <div class="owl-carousel">
                @foreach (block_id_lists($tv->recommendations->results) as $item)
                    @include(get_theme().'.components.item_tv', ['class' => ''])
                @endforeach
            </div>
        @endisset
    </section>

    @include(get_theme().'.components.modal_watch', ['backdrop' => $backdrop, 'id' => $tv->id, 'title' => $tv->original_name])
@endsection